==> gnustep-gui_0.9.5.orig.tar.gz: gnustep-gui-0.9.5.orig/Headers/AppKit/AppKitExceptions.h <==
/*
   AppKitExceptions.h

   Copyright (C) 1996 Free Software Foundation, Inc.

   Author: Ovidiu Predescu <ovidiu@net-community.com>
   Date: February 1997
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA.
*/
#ifndef __AppKit_AppKitExceptions_h__
#define __AppKit_AppKitExceptions_h__

#include <AppKit/AppKitDefines.h>

@class NSString;

APPKIT_EXPORT NSString *NSAbortModalException;
APPKIT_EXPORT NSString *NSAbortPrintingException;
APPKIT_EXPORT NSString *NSAppKitIgnoredException;
APPKIT_EXPORT NSString *NSAppKitVirtualMemoryException;
APPKIT_EXPORT NSString *NSBadBitmapParametersException;
APPKIT_EXPORT NSString *NSBadComparisonException;
APPKIT_EXPORT NSString *NSBadRTFColorTableException;
APPKIT_EXPORT NSString *NSBadRTFDirectiveException;
APPKIT_EXPORT NSString *NSBadRTFFontTableException;
APPKIT_EXPORT NSString *NSBadRTFStyleSheetException;
APPKIT_EXPORT NSString *NSBrowserIllegalDelegateException;
APPKIT_EXPORT NSString *NSColorListIOException;
APPKIT_EXPORT NSString *NSColorListNotEditableException;
APPKIT_EXPORT NSString *NSDraggingException;
APPKIT_EXPORT NSString *NSFontUnavailableException;
APPKIT_EXPORT NSString *NSIllegalSelectorException;
APPKIT_EXPORT NSString *NSImageCacheException;
APPKIT_EXPORT NSString *NSNibLoadingException;
APPKIT_EXPORT NSString *NSPPDIncludeNotFoundException;
APPKIT_EXPORT NSString *NSPPDIncludeStackOverflowException;
APPKIT_EXPORT NSString *NSPPDIncludeStackUnderflowException;
APPKIT_EXPORT NSString *NSPPDParseException;
APPKIT_EXPORT NSString *NSPasteboardCommunicationException;
APPKIT_EXPORT NSString *NSPrintOperationExistsException;
APPKIT_EXPORT NSString *NSPrintPackageException;
APPKIT_EXPORT NSString *NSPrintingCommunicationException;
APPKIT_EXPORT NSString *NSRTFPropertyStackOverflowException;
APPKIT_EXPORT NSString *NSTIFFException;
APPKIT_EXPORT NSString *NSTextLineTooLongException;
APPKIT_EXPORT NSString *NSTextNoSelectionException;
APPKIT_EXPORT NSString *NSTextReadException;
APPKIT_EXPORT NSString *NSTextWriteException;
APPKIT_EXPORT NSString *NSTypedStreamVersionException;
APPKIT_EXPORT NSString *NSWindowServerCommunicationException;
APPKIT_EXPORT NSString *NSWordTablesReadException;
APPKIT_EXPORT NSString *NSWordTablesWriteException;

#ifndef	NO_GNUSTEP
APPKIT_EXPORT NSString *GSWindowServerInternalException;
#endif

#endif /* __AppKit_AppKitExceptions_h__ */

==> gnustep-gui_0.11.0.orig.tar.gz: gnustep-gui-0.11.0/Headers/AppKit/AppKitExceptions.h <==
/*
   AppKitExceptions.h

   Copyright (C) 1996 Free Software Foundation, Inc.

   Author: Ovidiu Predescu <ovidiu@net-community.com>
   Date: February 1997
   
   This file is part of the GNUstep GUI Library.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
   
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with this library; if not, write to the Free
   Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02111 USA.
*/
#ifndef __AppKit_AppKitExceptions_h__
#define __AppKit_AppKitExceptions_h__

#include <AppKit/AppKitDefines.h>

@class NSString;

APPKIT_EXPORT NSString *NSAbortModalException;
APPKIT_EXPORT NSString *NSAbortPrintingException;
APPKIT_EXPORT NSString *NSAppKitIgnoredException;
APPKIT_EXPORT NSString *NSAppKitVirtualMemoryException;
APPKIT_EXPORT NSString *NSBadBitmapParametersException;
APPKIT_EXPORT NSString *NSBadComparisonException;
APPKIT_EXPORT NSString *NSBadRTFColorTableException;
APPKIT_EXPORT NSString *NSBadRTFDirectiveException;
APPKIT_EXPORT NSString *NSBadRTFFontTableException;
APPKIT_EXPORT NSString *NSBadRTFStyleSheetException;
APPKIT_EXPORT NSString *NSBrowserIllegalDelegateException;
APPKIT_EXPORT NSString *NSColorListIOException;
APPKIT_EXPORT NSString *NSColorListNotEditableException;
APPKIT_EXPORT NSString *NSDraggingException;
APPKIT_EXPORT NSString *NSFontUnavailableException;
APPKIT_EXPORT NSString *NSIllegalSelectorException;
APPKIT_EXPORT NSString *NSImageCacheException;
APPKIT_EXPORT NSString *NSNibLoadingException;
APPKIT_EXPORT NSString *NSPPDIncludeNotFoundException;
APPKIT_EXPORT NSString *NSPPDIncludeStackOverflowException;
APPKIT_EXPORT NSString *NSPPDIncludeStackUnderflowException;
APPKIT_EXPORT NSString *NSPPDParseException;
APPKIT_EXPORT NSString *NSPasteboardCommunicationException;
APPKIT_EXPORT NSString *NSPrintOperationExistsException;
APPKIT_EXPORT NSString *NSPrintPackageException;
APPKIT_EXPORT NSString *NSPrintingCommunicationException;
APPKIT_EXPORT NSString *NSRTFPropertyStackOverflowException;
APPKIT_EXPORT NSString *NSTIFFException;
APPKIT_EXPORT NSString *NSTextLineTooLongException;
APPKIT_EXPORT NSString *NSTextNoSelectionException;
APPKIT_EXPORT NSString *NSTextReadException;
APPKIT_EXPORT NSString *NSTextWriteException;
APPKIT_EXPORT NSString *NSTypedStreamVersionException;
APPKIT_EXPORT NSString *NSWindowServerCommunicationException;
APPKIT_EXPORT NSString *NSWordTablesReadException;
APPKIT_EXPORT NSString *NSWordTablesWriteException;

#ifndef	NO_GNUSTEP
APPKIT_EXPORT NSString *GSWindowServerInternalException;
#endif

#endif /* __AppKit_AppKitExceptions_h__ */
